AnyRefreshableController class
Controller for AnyRefreshableWidget that allows programmatic refresh triggering.
This controller provides methods to trigger refresh operations programmatically without requiring user interaction. It can be used to refresh the widget from anywhere in your code.
Example usage:
final controller = AnyRefreshableController();
// In your widget
AnyRefreshableWidget(
controller: controller,
onRefresh: [...],
builder: (context, isLoading, error) => ...,
)
// Trigger refresh programmatically
controller.refresh();
- Inheritance
-
- Object
- ChangeNotifier
- AnyRefreshableController
Constructors
Properties
- error → Object?
-
The current error, if any.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isAttached → bool
-
Whether the controller is currently attached to a widget.
no setter
- isRefreshing → bool
-
Whether any refresh operation is currently in progress.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
refresh(
) → Future< void> - Triggers a refresh operation programmatically.
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited